@@ -11,7 +11,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.0.2
     my $class = shift;
     my $mhead = shift // return undef;
@@ -322,7 +322,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::AmazonSES - bounce mail parser class for C<Amazon SES>.
+Sisimai::Lhost::AmazonSES - bounce mail decoder class for Amazon SES L<https://aws.amazon.com/ses/>
 
 =head1 SYNOPSIS
 
@@ -330,8 +330,9 @@ Sisimai::Lhost::AmazonSES - bounce mail parser class for C<Amazon SES>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::AmazonSES parses a bounce email or a JSON string which created by
-C<Amazon Simple Email Service>. Methods in the module are called from only C<Sisimai::Message>.
+C<Sisimai::Lhost::AmazonSES> decodes a bounce email or a JSON string which created by Amazon Simple
+Email Service L<https://aws.amazon.com/ses/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -343,7 +344,7 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference.
+C<inquire()> method decodes a bounced email and return results as a array reference.
 See C<Sisimai::Message> for more details.
 
 =head2 C<B<json(I<Hash>)>>
