@@ -11,7 +11,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.29
     my $class = shift;
     my $mhead = shift // return undef;
@@ -124,7 +124,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::AmazonWorkMail - bounce mail parser class for C<Amazon WorkMail>.
+Sisimai::Lhost::AmazonWorkMail - bounce mail decoder class for Amazon WorkMail L<https://aws.amazon.com/workmail/>.
 
 =head1 SYNOPSIS
 
@@ -132,8 +132,8 @@ Sisimai::Lhost::AmazonWorkMail - bounce mail parser class for C<Amazon WorkMail>
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::AmazonWorkMail parses a bounce email which created by C<Amazon WorkMail>. Methods in
-the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::AmazonWorkMail> decodes a bounce email which created by Amazon WorkMail L<https://aws.amazon.com/workmail/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -145,8 +145,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
