@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'Microsoft Exchange Server 2007' }
+sub description { 'Microsoft Exchange Server 2007: https://www.microsoft.com/microsoft-365/exchange/email' }
 sub inquire {
     # Detect an error from Microsoft Exchange Server 2007
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.1
     my $class = shift;
     my $mhead = shift // return undef;
@@ -168,7 +168,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::Exchange2007 - bounce mail parser class for C<Microsft Exchange Server 2007>.
+Sisimai::Lhost::Exchange2007 - bounce mail decoder class for Microsft Exchange Server 2007 L<https://www.microsoft.com/microsoft-365/exchange/email>.
 
 =head1 SYNOPSIS
 
@@ -176,8 +176,9 @@ Sisimai::Lhost::Exchange2007 - bounce mail parser class for C<Microsft Exchange
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Exchange2007 parses a bounce email which created by C<Microsoft Exchange Server 2007>.
-Methods in the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::Exchange2007> decodes a bounce email which created by Microsoft Exchange Server 2007
+L<https://www.microsoft.com/microsoft-365/exchange/email>. Methods in the module are called from only
+C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -189,8 +190,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -205,3 +206,4 @@ Copyright (C) 2016-2021,2023,2024 azumakuniyuki, All rights reserved.
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
