@@ -6,11 +6,11 @@ use warnings;
 
 sub description { 'Exim' }
 sub inquire {
-    # Detect an error from Exim
+    # Detect an error from Exim Internet Mailer
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -499,7 +499,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::Exim - bounce mail parser class for C<Exim>.
+Sisimai::Lhost::Exim - bounce mail decoder class for Exim Internet Mailer L<https://www.exim.org/>.
 
 =head1 SYNOPSIS
 
@@ -507,8 +507,8 @@ Sisimai::Lhost::Exim - bounce mail parser class for C<Exim>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Exim parses a bounce email which created by C<Exim>. Methods in the module are called
-from only Sisimai::Message.
+C<Sisimai::Lhost::Exim> decodes a bounce email which created by Exim Internet Mailer L<https://www.exim.org/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -520,8 +520,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -536,3 +536,4 @@ Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
