@@ -10,7 +10,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decodes or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -195,7 +195,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::Facebook - bounce mail parser class for C<Facebook>.
+Sisimai::Lhost::Facebook - bounce mail decoder class for Facebook L<https://www.facebook.com>.
 
 =head1 SYNOPSIS
 
@@ -203,8 +203,8 @@ Sisimai::Lhost::Facebook - bounce mail parser class for C<Facebook>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Facebook parses a bounce email which created by C<Facebook>. Methods in the module
-are called from only Sisimai::Message.
+C<Sisimai::Lhost::Facebook> decodes a bounce email which created by Facebook L<https://www.facebook.com>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -216,8 +216,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -232,3 +232,4 @@ Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
