@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'GMX: https://www.gmx.net' }
+sub description { 'GMX: https://gmx.net/' }
 sub inquire {
     # Detect an error from GMX and mail.com
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.4
     my $class = shift;
     my $mhead = shift // return undef;
@@ -122,7 +122,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::GMX - bounce mail parser class for C<GMX> and mail.com.
+Sisimai::Lhost::GMX - bounce mail decoder class for GMX L<https://gmx.net/> and mail.com.
 
 =head1 SYNOPSIS
 
@@ -130,8 +130,8 @@ Sisimai::Lhost::GMX - bounce mail parser class for C<GMX> and mail.com.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::GMX parses a bounce email which created by C<GMX>. Methods in the module are called
-from only Sisimai::Message.
+C<Sisimai::Lhost::GMX> decodes a bounce email which created by GMX L<https://gmx.net>. Methods in
+the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -143,8 +143,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
