@@ -10,7 +10,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.25.6
     my $class = shift;
     my $mhead = shift // return undef;
@@ -84,7 +84,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::GoogleGroups - bounce mail parser class for C<Google Groups>.
+Sisimai::Lhost::GoogleGroups - bounce mail decoder class for Google Groups L<https://groups.google.com>.
 
 =head1 SYNOPSIS
 
@@ -92,8 +92,8 @@ Sisimai::Lhost::GoogleGroups - bounce mail parser class for C<Google Groups>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::GoogleGroups parses a bounce email which created by C<Google Groups>. Methods in the
-module are called from only Sisimai::Message.
+C<Sisimai::Lhost::GoogleGroups> decodes a bounce email which created by Google Groups L<https://groups.google.com>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -105,8 +105,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
