@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'MailFoundry' }
+sub description { 'MailFoundry: https://www.barracuda.com/' }
 sub inquire {
     # Detect an error from MailFoundry
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.1
     my $class = shift;
     my $mhead = shift // return undef;
@@ -92,7 +92,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::MailFoundry - bounce mail parser class for C<MailFoundry>.
+Sisimai::Lhost::MailFoundry - bounce mail decoder class for MailFoundry L<https://www.barracuda.com/>.
 
 =head1 SYNOPSIS
 
@@ -100,8 +100,8 @@ Sisimai::Lhost::MailFoundry - bounce mail parser class for C<MailFoundry>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::MailFoundry parses a bounce email which created by C<MailFoundry>. Methods in the
-module are called from only Sisimai::Message.
+C<Sisimai::Lhost::MailFoundry> decodes a bounce email which created by MailFoundry L<https://www.barracuda.com/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -113,8 +113,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
