@@ -6,11 +6,11 @@ use warnings;
 
 sub description { 'McAfee Email Appliance' }
 sub inquire {
-    # Detect an error from McAfee
+    # Detect an error from McAfee Email Appliance
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.1
     my $class = shift;
     my $mhead = shift // return undef;
@@ -114,7 +114,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::McAfee - bounce mail parser class for C<McAfee Email Appliance>.
+Sisimai::Lhost::McAfee - bounce mail decode class for McAfee Email Appliance.
 
 =head1 SYNOPSIS
 
@@ -122,8 +122,8 @@ Sisimai::Lhost::McAfee - bounce mail parser class for C<McAfee Email Appliance>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::McAfee parses a bounce email which created by C<McAfee Email Appliance>. Methods in
-the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::McAfee> decodes a bounce email which created by McAfee Email Appliance.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -135,8 +135,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
