@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'Oracle Communications Messaging Server' }
+sub description { 'Oracle Communications Messaging Server: https://docs.oracle.com/en/industries/communications/messaging-server/index.html' }
 sub inquire {
     # Detect an error from Oracle Communications Messaging Server
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.3
     my $class = shift;
     my $mhead = shift // return undef;
@@ -162,8 +162,8 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::MessagingServer - bounce mail parser class for C<Sun Java System Messaging Server>
-and C<Oracle Communications Messaging Server>.
+Sisimai::Lhost::MessagingServer - bounce mail decoder class for C<Sun Java System Messaging Server>
+and C<Oracle Communications Messaging Server> L<https://docs.oracle.com/en/industries/communications/messaging-server/index.html>.
 
 =head1 SYNOPSIS
 
@@ -171,8 +171,9 @@ and C<Oracle Communications Messaging Server>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::MessagingServer parses a bounce email which created by C<Oracle Communications Messaging Server>
-and C<Sun Java System Messaging Server>. Methods in the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::MessagingServer> decodes a bounce email which created by Oracle Communications
+Messaging Server L<https://docs.oracle.com/en/industries/communications/messaging-server/index.html>
+and Sun Java System Messaging Server. Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -184,8 +185,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
