@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'OpenSMTPD' }
+sub description { 'OpenSMTPD: https://www.opensmtpd.org/' }
 sub inquire {
     # Detect an error from OpenSMTPD
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -60,7 +60,11 @@ sub inquire {
             'Domain does not exist',
         ],
         # smtp/mta.c:1085|  relay->failstr = "Destination seem to reject all mails";
-        'notaccept'   => ['Destination seem to reject all mails'],
+        'notaccept'   => [
+            'Destination seem to reject all mails',
+            'No MX found for domain',
+            'No MX found for destination',
+        ],
         'networkerror'=> [
             #  smtpd/mta.c:972|  relay->failstr = "Temporary failure in MX lookup";
             'Address family mismatch on destination MXs',
@@ -69,8 +73,6 @@ sub inquire {
             'Could not retrieve source address',
             'Loop detected',
             'Network error on destination MXs',
-            'No MX found for domain',
-            'No MX found for destination',
             'No valid route to remote MX',
             'No valid route to destination',
             'Temporary failure in MX lookup',
@@ -142,7 +144,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::OpenSMTPD - bounce mail parser class for C<OpenSMTPD>.
+Sisimai::Lhost::OpenSMTPD - bounce mail decoder class for OpenSMTPD L<https://www.opensmtpd.org/>.
 
 =head1 SYNOPSIS
 
@@ -150,8 +152,8 @@ Sisimai::Lhost::OpenSMTPD - bounce mail parser class for C<OpenSMTPD>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::OpenSMTPD parses a bounce email which created by C<OpenSMTPD>. Methods in the module
-are called from only Sisimai::Message.
+C<Sisimai::Lhost::OpenSMTPD> decodes a bounce email which created by OpenSMTPD L<https://www.opensmtpd.org/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -163,8 +165,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -179,3 +181,4 @@ Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
