@@ -4,13 +4,13 @@ use v5.26;
 use strict;
 use warnings;
 
-sub description { 'Postfix' }
+sub description { 'Postfix: https://www.postfix.org/' }
 sub inquire {
-    # Parse bounce messages from Postfix
+    # Decode bounce messages from Postfix
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.0.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -293,7 +293,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::Postfix - bounce mail parser class for C<Postfix>.
+Sisimai::Lhost::Postfix - bounce mail decoder class for Postfix L<https://www.postfix.org/>.
 
 =head1 SYNOPSIS
 
@@ -301,8 +301,8 @@ Sisimai::Lhost::Postfix - bounce mail parser class for C<Postfix>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::Postfix parses a bounce email which created by C<Postfix>. Methods in the module are
-called from only Sisimai::Message.
+C<Sisimai::Lhost::Postfix> decodes a bounce email which created by Postfix L<https://www.postfix.org/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -314,8 +314,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
