@@ -4,14 +4,14 @@ use v5.26;
 use strict;
 use warnings;
 
-# https://aws.amazon.com/ses/
 sub description { 'Amazon SES(Receiving): https://aws.amazon.com/ses/' };
 sub inquire {
     # Detect an error from Amazon SES/Receiving
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
+    # @see      https://aws.amazon.com/ses/
     # @since v4.1.29
     my $class = shift;
     my $mhead = shift // return undef;
@@ -133,7 +133,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::ReceivingSES - bounce mail parser class for C<Amazon SES>.
+Sisimai::Lhost::ReceivingSES - bounce mail decoder class for Amazon SES C<https://aws.amazon.com/ses/>.
 
 =head1 SYNOPSIS
 
@@ -141,8 +141,8 @@ Sisimai::Lhost::ReceivingSES - bounce mail parser class for C<Amazon SES>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::ReceivingSES parses a bounce email which created by C<Amazon Simple Email Service>.
-Methods in the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::ReceivingSES> decodes a bounce email which created by Amazon Simple Email Service
+L<https://aws.amazon.com/ses/>. Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -154,8 +154,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
