@@ -10,7 +10,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.2
     my $class = shift;
     my $mhead = shift // return undef;
@@ -79,7 +79,7 @@ sub inquire {
             $v->{'diagnosis'} = Sisimai::String->sweep(substr($e, $p2 + 2,));
 
         } else {
-            # Fallback, parse RFC3464 headers.
+            # Fallback, read RFC3464 headers.
             if( my $f = Sisimai::RFC1894->match($e) ) {
                 # $e matched with any field defined in RFC3464
                 next unless my $o = Sisimai::RFC1894->field($e);
@@ -111,7 +111,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::SurfControl - bounce mail parser class for C<SurfControl>.
+Sisimai::Lhost::SurfControl - bounce mail decoder class for SurfControl.
 
 =head1 SYNOPSIS
 
@@ -119,8 +119,8 @@ Sisimai::Lhost::SurfControl - bounce mail parser class for C<SurfControl>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::SurfControl parses a bounce email which created by C<WebSense SurfControl>. Methods
-in the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::SurfControl> decodes a bounce email which created by WebSense SurfControl.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -132,8 +132,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
