@@ -10,7 +10,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.2
     my $class = shift;
     my $mhead = shift // return undef;
@@ -160,7 +160,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::V5sendmail - bounce mail parser class for C<V5 Sendmail>.
+Sisimai::Lhost::V5sendmail - bounce mail decoder class for V5 Sendmail.
 
 =head1 SYNOPSIS
 
@@ -168,8 +168,8 @@ Sisimai::Lhost::V5sendmail - bounce mail parser class for C<V5 Sendmail>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::V5sendmail parses a bounce email which created by C<Sendmail version 5> or any email
-appliances based on C<Sendmail version 5>. Methods in the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::V5sendmail> decodes a bounce email which created by Sendmail version 5 or any email
+appliances based on Sendmail version 5. Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -181,8 +181,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -197,3 +197,4 @@ Copyright (C) 2014-2021,2023,2024 azumakuniyuki, All rights reserved.
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
