@@ -10,7 +10,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.13.0
     my $class = shift;
     my $mhead = shift // return undef;
@@ -120,7 +120,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::X5 - bounce mail parser class for unknown MTA #5.
+Sisimai::Lhost::X5 - bounce mail decoder class for unknown MTA #5.
 
 =head1 SYNOPSIS
 
@@ -128,8 +128,8 @@ Sisimai::Lhost::X5 - bounce mail parser class for unknown MTA #5.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::X5 parses a bounce email which created by Unknown MTA #5. Methods in the module are
-called from only Sisimai::Message.
+C<Sisimai::Lhost::X5> decodes a bounce email which created by Unknown MTA #5. Methods in the module
+are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -141,8 +141,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
