@@ -4,18 +4,14 @@ use strict;
 use warnings;
 
 sub inquire {
-    # Parse message body and return reason and text
+    # Decode the message body and return the MDA name, the reason and the error message text
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     my $class = shift;
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
-
-    return undef unless defined $mhead;
-    return undef unless length $$mbody;
-
     my $mfrom = lc $mhead->{'from'};
     my $match = 0;
 
@@ -141,7 +137,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::MDA - Error message parser for MDA
+Sisimai::MDA - Error message decoder for MDA
 
 =head1 SYNOPSIS
 
@@ -152,14 +148,14 @@ Sisimai::MDA - Error message parser for MDA
 
 =head1 DESCRIPTION
 
-Sisimai::MDA parse bounced email which created by some MDA, such as C<dovecot>, C<mail.local>,
-C<procmail>, and so on. This class is called from Sisimai::Message only.
+C<Sisimai::MDA> decodes bounced email which created by some MDA, such as Dovecot, C<mail.local>,
+C<procmail>, and so on. This class is called from C<Sisimai::Message> only.
 
 =head1 CLASS METHODS
 
 =head2 C<B<inquire(I<Header>, I<Reference to message body>)>>
 
-C<inquire()> is a parser for detecting an error from mail delivery agent.
+C<inquire()> is a decoder for detecting an error from the mail delivery agent.
 
     my $header = { 'from' => 'mailer-daemon@example.jp' };
     my $string = 'mail.local: Disc quota exceeded';
@@ -184,3 +180,4 @@ Copyright (C) 2014-2016,2018-2024 azumakuniyuki, All rights reserved.
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
