@@ -263,13 +263,13 @@ Sisimai::RFC5322 - Email address related utilities
 
 =head1 DESCRIPTION
 
-Sisimai::RFC5322 provide methods for checking email address.
+C<Sisimai::RFC5322> provide methods for checking an email address.
 
 =head1 CLASS METHODS
 
 =head2 C<B<received(I<String>)>>
 
-C<received()> returns array reference including elements in the Received header.
+C<received()> method returns an array reference including elements in the C<Received:> header.
 
     my $v = 'from mx.example.org (c1.example.org [192.0.2.1]) by neko.libsisimai.org
              with ESMTP id neko20180202nyaan for <michitsuna@nyaan.jp>; ...';
@@ -287,8 +287,8 @@ C<received()> returns array reference including elements in the Received header.
 
 =head2 C<B<part(I<String>, I<Array>)>>
 
-C<part()> returns array reference which include error message lines of given message body and the
-original message part split by the 2nd argument.
+C<part()> method returns an array reference which include error message lines of given message body
+and the original message part splitted by the 2nd argument.
 
     my $v = 'Error message here
     Content-Type: message/rfc822
@@ -314,3 +314,4 @@ Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
