@@ -54,18 +54,18 @@ Sisimai::Reason::ContentError - Bounce reason is C<contenterror> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::ContentError checks the bounce reason is C<contenterror> or not. This class is called
-only Sisimai::Reason class.
+C<Sisimai::Reason::ContentError> checks the bounce reason is C<contenterror> or not. This class is
+called only C<Sisimai::Reason> class.
 
-This is the error that a destination mail server has rejected email due to header format of the email
-like the following. Sisimai will set C<contenterror> to the reason of email bounce if the value of
-Status: field in a bounce email is "5.6.*".
+This is the error that the destination mail server has rejected email due to the header format of
+the email like the following. Sisimai will set C<contenterror> to the reason of the email bounce if
+the value of C<Status:> field in a bounce email is C<5.6.*>.
 
 =over
 
 =item - 8 bit data in message header
 
-=item - Too many "Received" headers
+=item - Too many C<Received:> headers
 
 =item - Invalid MIME headers
 
@@ -80,20 +80,20 @@ Status: field in a bounce email is "5.6.*".
 
 =head2 C<B<text()>>
 
-C<text()> returns string: C<contenterror>.
+C<text()> method returns the fixed string C<contenterror>.
 
     print Sisimai::Reason::ContentError->text;  # contenterror
 
 =head2 C<B<match(I<string>)>>
 
-C<match()> returns 1 if the argument matched with patterns defined in this class.
+C<match()> method returns C<1> if the argument matched with patterns defined in this class.
 
     print Sisimai::Reason::ContentError->match('550 Message Filterd'); # 1
 
 =head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<contenterror>. The argument must be Sisimai::Fact object
-and this method is called only from Sisimai::Reason class.
+C<true()> method returns C<1> if the bounce reason is C<contenterror>. The argument must be C<Sisimai::Fact>
+object and this method is called only from C<Sisimai::Reason> class.
 
 =head1 AUTHOR
 
