@@ -57,10 +57,10 @@ Sisimai::Reason::MailerError - Bounce reason is C<mailererror> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::MailerError checks the bounce reason is C<mailererror> or not. This class is called
-only Sisimai::Reason class.
+C<Sisimai::Reason::MailerError> checks the bounce reason is C<mailererror> or not. This class is
+called only C<Sisimai::Reason> class.
 
-This is the error that a mailer program has not exited successfully or exited unexpectedly on a
+This is the error that the mailer program has not exited successfully or exited unexpectedly on the
 destination mail server.
 
     X-Actual-Recipient: X-Unix; |/home/kijitora/mail/catch.php
@@ -70,20 +70,20 @@ destination mail server.
 
 =head2 C<B<text()>>
 
-C<text()> returns string: C<mailererror>.
+C<text()> method returns the fixed string C<mailererror>.
 
     print Sisimai::Reason::MailerError->text;  # mailererror
 
 =head2 C<B<match(I<string>)>>
 
-C<match()> returns 1 if the argument matched with patterns defined in this class.
+C<match()> method returns C<1> if the argument matched with patterns defined in this class.
 
     print Sisimai::Reason::MailerError->match('X-Unix; 255');   # 1
 
 =head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<mailererror>. The argument must be Sisimai::Fact object
-and this method is called only from Sisimai::Reason class.
+C<true()> method returns C<1> if the bounce reason is C<mailererror>. The argument must be C<Sisimai::Fact>
+object and this method is called only from C<Sisimai::Reason> class.
 
 =head1 AUTHOR
 
@@ -98,3 +98,4 @@ Copyright (C) 2014-2017,2020,2021,2023,2024 azumakuniyuki, All rights reserved.
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
