@@ -1,5 +1,5 @@
 package Sisimai::Reason::NoRelaying;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -16,17 +16,26 @@ sub match {
 
     state $index = [
         'as a relay',
+        'email address is not verified.',
         'insecure mail relay',
-        'mail server requires authentication when attempting to send to a non-local e-mail address',    # MailEnable 
+        'is not permitted to relay through this server without authentication',
+        'mail server requires authentication when attempting to send to a non-local e-mail address',    # MailEnable
+        'no relaying',
+        'not a gateway',
         'not allowed to relay through this machine',
         'not an open relay, so get lost',
+        'not local host',
         'relay access denied',
         'relay denied',
+        'relaying mail to ',
         'relay not permitted',
         'relaying denied',  # Sendmail
+        'relaying mail to ',
+        'specified domain is not allowed',
         "that domain isn't in my list of allowed rcpthost",
         'this system is not configured to relay mail',
         'unable to relay for',
+        "we don't handle mail for",
     ];
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
     return 0;
@@ -34,21 +43,21 @@ sub match {
 
 sub true {
     # Whether the message is rejected by 'Relaying denied'
-    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @param    [Sisimai::Fact] argvs   Object to be detected the reason
     # @return   [Integer]               1: Rejected for "relaying denied"
-    #                                   0: is not 
+    #                                   0: is not
     # @since v4.0.0
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
     my $argvs = shift // return undef;
 
-    if( my $r = $argvs->reason // '' ) {
-        # Do not overwrite the reason
-        return 0 if( $r eq 'securityerror' || $r eq 'systemerror' || $r eq 'undefined' );
-    } else {
-        # Check the value of Diagnosic-Code: header with patterns
-        return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
-    }
+    return 0 if $argvs->{'reason'} eq 'securityerror'
+             || $argvs->{'reason'} eq 'systemerror'
+             || $argvs->{'reason'} eq 'undefined';
+    return 0 if $argvs->{'smtpcommand'} eq 'CONN'
+             || $argvs->{'smtpcommand'} eq 'EHLO'
+             || $argvs->{'smtpcommand'} eq 'HELO';
+    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
     return 0;
 }
 
@@ -68,11 +77,9 @@ Sisimai::Reason::NoRelaying - Bounce reason is C<norelaying> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::NoRelaying checks the bounce reason is C<norelaying> or not.
-This class is called only Sisimai::Reason class.
-
-This is the error that SMTP connection rejected with error message 
-C<Relaying Denied>. This reason does not exist in any version of bounceHammer.
+C<Sisimai::Reason::NoRelaying> checks the bounce reason is C<norelaying> or not. This class is called
+only C<Sisimai::Reason> class. This is the error that the SMTP connection rejected with an error message
+like C<Relaying Denied>.
 
     ... while talking to mailin-01.mx.example.com.:
     >>> RCPT To:<kijitora@example.org>
@@ -83,20 +90,20 @@ C<Relaying Denied>. This reason does not exist in any version of bounceHammer.
 
 =head2 C<B<text()>>
 
-C<text()> returns string: C<norelaying>.
+C<text()> method returns the fixed string C<norelaying>.
 
     print Sisimai::Reason::NoRelaying->text;  # norelaying
 
 =head2 C<B<match(I<string>)>>
 
-C<match()> returns 1 if the argument matched with patterns defined in this class.
+C<match()> method returns C<1> if the argument matched with patterns defined in this class.
 
     print Sisimai::Reason::NoRelaying->match('Relaying denied');   # 1
 
-=head2 C<B<true(I<Sisimai::Data>)>>
+=head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<norelaying>. The argument must be
-Sisimai::Data object and this method is called only from Sisimai::Reason class.
+C<true()> method returns C<1> if the bounce reason is C<norelaying>. The argument must be C<Sisimai::Fact>
+object and this method is called only from C<Sisimai::Reason> class.
 
 =head1 AUTHOR
 
@@ -104,10 +111,11 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018,2020-2023,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
