@@ -76,28 +76,28 @@ Sisimai::Reason::Suspend - Bounce reason is C<suspend> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::Suspend checks the bounce reason is C<suspend> or not. This class is called only
-Sisimai::Reason class. This is the error that a recipient account is being suspended due to unpaid
-or other reasons.
+C<Sisimai::Reason::Suspend> checks the bounce reason is C<suspend> or not. This class is called only
+C<Sisimai::Reason> class. This is the error that the recipient account is being suspended due to
+unpaid, or being inactive, or other reasons.
 
 =head1 CLASS METHODS
 
 =head2 C<B<text()>>
 
-C<text()> returns string: C<suspend>.
+C<text()> method returns the fixed string C<suspend>.
 
     print Sisimai::Reason::Suspend->text;  # suspend
 
 =head2 C<B<match(I<string>)>>
 
-C<match()> returns 1 if the argument matched with patterns defined in this class.
+C<match()> method returns C<1> if the argument matched with patterns defined in this class.
 
     print Sisimai::Reason::Suspend->match('recipient suspend the service'); # 1
 
 =head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<suspend>. The argument must be Sisimai::Fact object
-and this method is called only from Sisimai::Reason class.
+C<true()> method returns C<1> if the bounce reason is C<suspend>. The argument must be C<Sisimai::Fact>
+object and this method is called only from C<Sisimai::Reason> class.
 
 =head1 AUTHOR
 
