@@ -66,11 +66,11 @@ Sisimai::Reason::TooManyConn - Bounced due to that too many connections.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::TooManyConn checks the bounce reason is C<toomanyconn> or not. This class is called
-only Sisimai::Reason class.
+C<Sisimai::Reason::TooManyConn> checks the bounce reason is C<toomanyconn> or not. This class is
+called only C<Sisimai::Reason> class.
 
-This is the error that SMTP connection was rejected temporarily due to too many concurrency connections
-to the remote server. This reason has added in Sisimai 4.1.26.
+This is the error that the SMTP connection was rejected temporarily due to too many concurrency
+connections to the remote server. This reason has added in Sisimai 4.1.26.
 
     <kijitora@example.ne.jp>: host mx02.example.ne.jp[192.0.1.20] said:
         452 4.3.2 Connection rate limit exceeded. (in reply to MAIL FROM command)
@@ -79,20 +79,20 @@ to the remote server. This reason has added in Sisimai 4.1.26.
 
 =head2 C<B<text()>>
 
-C<text()> returns string: C<toomanyconn>.
+C<text()> method returns the fixed string C<toomanyconn>.
 
     print Sisimai::Reason::TooManyConn->text;  # toomanyconn
 
 =head2 C<B<match(I<string>)>>
 
-C<match()> returns 1 if the argument matched with patterns defined in this class.
+C<match()> method returns C<1> if the argument matched with patterns defined in this class.
 
     print Sisimai::Reason::TooManyConn->match('Connection rate limit exceeded');  # 1
 
 =head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> returns 1 if the bounce reason is C<toomanyconn>. The argument must be Sisimai::Fact
-object and this method is called only from Sisimai::Reason class.
+C<true()> method returns C<1> if the bounce reason is C<toomanyconn>. The argument must be
+C<Sisimai::Fact> object and this method is called only from C<Sisimai::Reason> class.
 
 =head1 AUTHOR
 
@@ -108,4 +108,3 @@ This software is distributed under The BSD 2-Clause License.
 
 =cut
 
-
