@@ -4,6 +4,7 @@ use strict;
 use warnings;
 
 state $RhostClass = {
+    'Apple'     => ['.mail.icloud.com', '.apple.com', '.me.com'],
     'Cox'       => ['cox.net'],
     'FrancePTT' => ['.laposte.net', '.orange.fr', '.wanadoo.fr'],
     'GoDaddy'   => ['smtp.secureserver.net', 'mailstore1.secureserver.net'],
@@ -15,42 +16,30 @@ state $RhostClass = {
     'NTTDOCOMO' => ['mfsmax.docomo.ne.jp'],
     'Spectrum'  => ['charter.net'],
     'Tencent'   => ['.qq.com'],
+    'YahooInc'  => ['.yahoodns.net'],
 };
 
-sub match {
-    # The value of "rhost" is listed in RhostClass or not
-    # @param    [String] argv1  Remote host name
-    # @return   [Integer]       0: did not match
-    #                           1: match
-    my $class = shift;
-    my $rhost = shift // return undef;
-    my $host0 = lc($rhost) || return 0;
-    my $match = 0;
-
-    for my $e ( keys %$RhostClass ) {
-        # Try to match with each key of RhostClass
-        next unless grep { index($host0, $_) > -1 } $RhostClass->{ $e }->@*;
-        $match = 1;
-        last;
-    }
-    return $match;
-}
-
 sub get {
     # Detect the bounce reason from certain remote hosts
-    # @param    [Sisimai::Fact] argvs   Parsed email object
-    # @param    [String]        proxy   The alternative of the "rhost"
+    # @param    [Sisimai::Fact] argvs   Decoded email object
     # @return   [String]                The value of bounce reason
     my $class = shift;
     my $argvs = shift || return undef;
-    my $proxy = shift || undef;
+    return undef unless length $argvs->{'diagnosticcode'};
 
-    my $remotehost = $proxy || lc $argvs->{'rhost'};
+    my $remotehost = lc $argvs->{'rhost'}       || '';
+    my $domainpart = lc $argvs->{'destination'} || '';
+    return undef unless length $remotehost.$domainpart;
+
+    my $rhostmatch = undef;
     my $rhostclass = '';
 
     for my $e ( keys %$RhostClass ) {
-        # Try to match with each key of RhostClass
-        next unless grep { index($remotehost, $_) > -1 } $RhostClass->{ $e }->@*;
+        # Try to match with each value of RhostClass
+        $rhostmatch   = 1 if grep { index($remotehost, $_) > -1 } $RhostClass->{ $e }->@*;
+        $rhostmatch ||= 1 if grep { index($domainpart, $_) > -1 } $RhostClass->{ $e }->@*;
+        next unless $rhostmatch;
+
         $rhostclass = __PACKAGE__.'::'.$e;
         last;
     }
@@ -76,19 +65,15 @@ Sisimai::Rhost - Detect the bounce reason returned from certain remote hosts.
 
 =head1 DESCRIPTION
 
-Sisimai::Rhost detects the bounce reason from the content of Sisimai::Fact object as an argument of
-get() method when the value of C<rhost> of the object is listed in $RhostClass variable. This class
-is called only Sisimai::Fact class.
+C<Sisimai::Rhost> detects the bounce reason from the content of C<Sisimai::Fact> object as an argument
+of C<get()> method when the value of C<rhost> of the object is listed in C<$RhostClass> variable.
+This class is called only C<Sisimai::Fact> class.
 
 =head1 CLASS METHODS
 
-=head2 C<B<match(I<remote host>)>>
-
-Returns 1 if the remote host is listed in $RhostClass variable.
-
 =head2 C<B<get(I<Sisimai::Fact Object>)>>
 
-C<get()> detects the bounce reason.
+C<get()> method detects the bounce reason.
 
 =head1 AUTHOR
 
