@@ -5,16 +5,17 @@ use warnings;
 
 sub get {
     # Detect bounce reason from au(KDDI)
-    # @param    [Sisimai::Fact] argvs   Parsed email object
+    # @param    [Sisimai::Fact] argvs   Decoded email object
     # @return   [String]                The bounce reason au.com and ezweb.ne.jp
+    # @since v4.22.6
     my $class = shift;
     my $argvs = shift // return undef;
 
     state $messagesof = {
-        'filtered'    => '550 : User unknown',  # The response was: 550 : User unknown
-        'userunknown' => '>: User unknown',     # The response was: 550 <...>: User unknown
+        'filtered'    => '550 : user unknown',  # The response was: 550 : User unknown
+        'userunknown' => '>: user unknown',     # The response was: 550 <...>: User unknown
     };
-    my $issuedcode = $argvs->{'diagnosticcode'};
+    my $issuedcode = lc $argvs->{'diagnosticcode'};
     my $reasontext = '';
 
     for my $e ( keys %$messagesof ) {
@@ -37,19 +38,19 @@ Sisimai::Rhost::KDDI - Detect the bounce reason returned from au (KDDI).
 
 =head1 SYNOPSIS
 
-    use Sisimai::Rhost;
+    use Sisimai::Rhost::KDDI;
 
 =head1 DESCRIPTION
 
-Sisimai::Rhost detects the bounce reason from the content of Sisimai::Fact object as an argument
-of get() method when the value of C<rhost> of the object is "msmx.au.com" or "lsean.ezweb.ne.jp".
-This class is called only Sisimai::Fact class.
+C<Sisimai::Rhost::KDDI> detects the bounce reason from the content of C<Sisimai::Fact> object as an
+argument of C<get()> method when the value of C<rhost> of the object is C<msmx.au.com> or C<lsean.ezweb.ne.jp>.
+This class is called only C<Sisimai::Fact> class.
 
 =head1 CLASS METHODS
 
 =head2 C<B<get(I<Sisimai::Fact Object>)>>
 
-C<get()> detects the bounce reason.
+C<get()> method detects the bounce reason.
 
 =head1 AUTHOR
 
