@@ -9,14 +9,12 @@ use Sisimai::SMTP::Status;
 # https://learn.microsoft.com/en-us/Exchange/mail-flow/non-delivery-reports-and-bounce-messages/non-delivery-reports-and-bounce-messages
 sub get {
     # Detect bounce reason from Exchange Server 2019 or older and Exchange Online
-    # @param    [Sisimai::Fact] argvs   Parsed email object
+    # @param    [Sisimai::Fact] argvs   Decoded email object
     # @return   [String]                The bounce reason for Exchange Online
     # @see      https://technet.microsoft.com/en-us/library/bb232118
+    # @since v4.17.2
     my $class = shift;
     my $argvs = shift // return undef;
-
-    return $argvs->{'reason'} if $argvs->{'reason'};
-    return '' unless $argvs->{'diagnosticcode'};
     return '' unless $argvs->{'deliverystatus'};
     return '' unless Sisimai::SMTP::Status->test($argvs->{'deliverystatus'});
 
@@ -761,19 +759,19 @@ older and Office 365.
 
 =head1 SYNOPSIS
 
-    use Sisimai::Rhost;
+    use Sisimai::Rhost::Microsoft;
 
 =head1 DESCRIPTION
 
-Sisimai::Rhost detects the bounce reason from the content of Sisimai::Fact object as an argument
-of get() method when the value of C<rhost> of the object is "*.protection.outlook.com". This class
-is called only Sisimai::Fact class.
+C<Sisimai::Rhost::Microsoft> detects the bounce reason from the content of C<Sisimai::Fact> object
+as an argument of C<get()> method when the value of C<rhost> of the object is C<*.protection.outlook.com>.
+This class is called only C<Sisimai::Fact> class.
 
 =head1 CLASS METHODS
 
 =head2 C<B<get(I<Sisimai::Fact Object>)>>
 
-C<get()> detects the bounce reason.
+C<get()> method detects the bounce reason.
 
 =head1 AUTHOR
 
