@@ -5,7 +5,7 @@ use warnings;
 
 sub get {
     # Detect bounce reason from NTT docomo
-    # @param    [Sisimai::Fact] argvs   Parsed email object
+    # @param    [Sisimai::Fact] argvs   Decoded email object
     # @return   [String]                The bounce reason for docomo.ne.jp
     # @since v4.25.15
     my $class = shift;
@@ -121,19 +121,19 @@ Sisimai::Rhost::NTTDOCOMO - Detect the bounce reason returned from NTT docomo.
 
 =head1 SYNOPSIS
 
-    use Sisimai::Rhost;
+    use Sisimai::Rhost::NTTDOCOMO;
 
 =head1 DESCRIPTION
 
-Sisimai::Rhost detects the bounce reason from the content of Sisimai::Fact object as an argument
-of get() method when the value of C<rhost> of the object is "mfsmax.docomo.ne.jp". This class is
-called only Sisimai::Fact class.
+C<Sisimai::Rhost::NTTDOCOMO> detects the bounce reason from the content of C<Sisimai::Fact> object
+as an argument of C<get()> method when the value of C<rhost> of the object is C<mfsmax.docomo.ne.jp>.
+This class is called only C<Sisimai::Fact> class.
 
 =head1 CLASS METHODS
 
 =head2 C<B<get(I<Sisimai::Fact Object>)>>
 
-C<get()> detects the bounce reason.
+C<get()> method detects the bounce reason.
 
 =head1 AUTHOR
 
